/* datetime.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __DATETIME_H__
#define __DATETIME_H__

#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <glib-object.h>
#include <gee.h>
#include <wingpanel.h>
#include <gio/gio.h>
#include <gmodule.h>
#include <gtk/gtk.h>
#include <libical-glib/libical-glib.h>
#include <libedataserver/libedataserver.h>
#include <libecal/libecal.h>

G_BEGIN_DECLS

#define GETTEXT_PACKAGE "datetime-indicator"
#define LOCALEDIR "/usr/share/locale"
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define UTIL_TYPE_DATE_ITERATOR (util_date_iterator_get_type ())
#define UTIL_DATE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), UTIL_TYPE_DATE_ITERATOR, UtilDateIterator))
#define UTIL_DATE_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), UTIL_TYPE_DATE_ITERATOR, UtilDateIteratorClass))
#define UTIL_IS_DATE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), UTIL_TYPE_DATE_ITERATOR))
#define UTIL_IS_DATE_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), UTIL_TYPE_DATE_ITERATOR))
#define UTIL_DATE_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), UTIL_TYPE_DATE_ITERATOR, UtilDateIteratorClass))

typedef struct _UtilDateIterator UtilDateIterator;
typedef struct _UtilDateIteratorClass UtilDateIteratorClass;
typedef struct _UtilDateIteratorPrivate UtilDateIteratorPrivate;

#define UTIL_TYPE_DATE_RANGE (util_date_range_get_type ())
#define UTIL_DATE_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), UTIL_TYPE_DATE_RANGE, UtilDateRange))
#define UTIL_DATE_RANGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), UTIL_TYPE_DATE_RANGE, UtilDateRangeClass))
#define UTIL_IS_DATE_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), UTIL_TYPE_DATE_RANGE))
#define UTIL_IS_DATE_RANGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), UTIL_TYPE_DATE_RANGE))
#define UTIL_DATE_RANGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), UTIL_TYPE_DATE_RANGE, UtilDateRangeClass))

typedef struct _UtilDateRange UtilDateRange;
typedef struct _UtilDateRangeClass UtilDateRangeClass;
typedef struct _UtilDateRangePrivate UtilDateRangePrivate;

#define DATE_TIME_TYPE_INDICATOR (date_time_indicator_get_type ())
#define DATE_TIME_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATE_TIME_TYPE_INDICATOR, DateTimeIndicator))
#define DATE_TIME_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATE_TIME_TYPE_INDICATOR, DateTimeIndicatorClass))
#define DATE_TIME_IS_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATE_TIME_TYPE_INDICATOR))
#define DATE_TIME_IS_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATE_TIME_TYPE_INDICATOR))
#define DATE_TIME_INDICATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATE_TIME_TYPE_INDICATOR, DateTimeIndicatorClass))

typedef struct _DateTimeIndicator DateTimeIndicator;
typedef struct _DateTimeIndicatorClass DateTimeIndicatorClass;
typedef struct _DateTimeIndicatorPrivate DateTimeIndicatorPrivate;

#define DATE_TIME_TYPE_COMPONENT_ROW (date_time_component_row_get_type ())
#define DATE_TIME_COMPONENT_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATE_TIME_TYPE_COMPONENT_ROW, DateTimeComponentRow))
#define DATE_TIME_COMPONENT_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATE_TIME_TYPE_COMPONENT_ROW, DateTimeComponentRowClass))
#define DATE_TIME_IS_COMPONENT_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATE_TIME_TYPE_COMPONENT_ROW))
#define DATE_TIME_IS_COMPONENT_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATE_TIME_TYPE_COMPONENT_ROW))
#define DATE_TIME_COMPONENT_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATE_TIME_TYPE_COMPONENT_ROW, DateTimeComponentRowClass))

typedef struct _DateTimeComponentRow DateTimeComponentRow;
typedef struct _DateTimeComponentRowClass DateTimeComponentRowClass;
typedef struct _DateTimeComponentRowPrivate DateTimeComponentRowPrivate;

#define DATE_TIME_WIDGETS_TYPE_PANEL_LABEL (date_time_widgets_panel_label_get_type ())
#define DATE_TIME_WIDGETS_PANEL_LABEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATE_TIME_WIDGETS_TYPE_PANEL_LABEL, DateTimeWidgetsPanelLabel))
#define DATE_TIME_WIDGETS_PANEL_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATE_TIME_WIDGETS_TYPE_PANEL_LABEL, DateTimeWidgetsPanelLabelClass))
#define DATE_TIME_WIDGETS_IS_PANEL_LABEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATE_TIME_WIDGETS_TYPE_PANEL_LABEL))
#define DATE_TIME_WIDGETS_IS_PANEL_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATE_TIME_WIDGETS_TYPE_PANEL_LABEL))
#define DATE_TIME_WIDGETS_PANEL_LABEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATE_TIME_WIDGETS_TYPE_PANEL_LABEL, DateTimeWidgetsPanelLabelClass))

typedef struct _DateTimeWidgetsPanelLabel DateTimeWidgetsPanelLabel;
typedef struct _DateTimeWidgetsPanelLabelClass DateTimeWidgetsPanelLabelClass;
typedef struct _DateTimeWidgetsPanelLabelPrivate DateTimeWidgetsPanelLabelPrivate;

#define DATE_TIME_WIDGETS_TYPE_CALENDAR_MODEL (date_time_widgets_calendar_model_get_type ())
#define DATE_TIME_WIDGETS_CALENDAR_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATE_TIME_WIDGETS_TYPE_CALENDAR_MODEL, DateTimeWidgetsCalendarModel))
#define DATE_TIME_WIDGETS_CALENDAR_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATE_TIME_WIDGETS_TYPE_CALENDAR_MODEL, DateTimeWidgetsCalendarModelClass))
#define DATE_TIME_WIDGETS_IS_CALENDAR_MODEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATE_TIME_WIDGETS_TYPE_CALENDAR_MODEL))
#define DATE_TIME_WIDGETS_IS_CALENDAR_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATE_TIME_WIDGETS_TYPE_CALENDAR_MODEL))
#define DATE_TIME_WIDGETS_CALENDAR_MODEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATE_TIME_WIDGETS_TYPE_CALENDAR_MODEL, DateTimeWidgetsCalendarModelClass))

typedef struct _DateTimeWidgetsCalendarModel DateTimeWidgetsCalendarModel;
typedef struct _DateTimeWidgetsCalendarModelClass DateTimeWidgetsCalendarModelClass;
typedef struct _DateTimeWidgetsCalendarModelPrivate DateTimeWidgetsCalendarModelPrivate;

#define DATE_TIME_WIDGETS_TYPE_CALENDAR_VIEW (date_time_widgets_calendar_view_get_type ())
#define DATE_TIME_WIDGETS_CALENDAR_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATE_TIME_WIDGETS_TYPE_CALENDAR_VIEW, DateTimeWidgetsCalendarView))
#define DATE_TIME_WIDGETS_CALENDAR_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATE_TIME_WIDGETS_TYPE_CALENDAR_VIEW, DateTimeWidgetsCalendarViewClass))
#define DATE_TIME_WIDGETS_IS_CALENDAR_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATE_TIME_WIDGETS_TYPE_CALENDAR_VIEW))
#define DATE_TIME_WIDGETS_IS_CALENDAR_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATE_TIME_WIDGETS_TYPE_CALENDAR_VIEW))
#define DATE_TIME_WIDGETS_CALENDAR_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATE_TIME_WIDGETS_TYPE_CALENDAR_VIEW, DateTimeWidgetsCalendarViewClass))

typedef struct _DateTimeWidgetsCalendarView DateTimeWidgetsCalendarView;
typedef struct _DateTimeWidgetsCalendarViewClass DateTimeWidgetsCalendarViewClass;
typedef struct _DateTimeWidgetsCalendarViewPrivate DateTimeWidgetsCalendarViewPrivate;

#define DATE_TIME_WIDGETS_TYPE_GRID (date_time_widgets_grid_get_type ())
#define DATE_TIME_WIDGETS_GRID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATE_TIME_WIDGETS_TYPE_GRID, DateTimeWidgetsGrid))
#define DATE_TIME_WIDGETS_GRID_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATE_TIME_WIDGETS_TYPE_GRID, DateTimeWidgetsGridClass))
#define DATE_TIME_WIDGETS_IS_GRID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATE_TIME_WIDGETS_TYPE_GRID))
#define DATE_TIME_WIDGETS_IS_GRID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATE_TIME_WIDGETS_TYPE_GRID))
#define DATE_TIME_WIDGETS_GRID_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATE_TIME_WIDGETS_TYPE_GRID, DateTimeWidgetsGridClass))

typedef struct _DateTimeWidgetsGrid DateTimeWidgetsGrid;
typedef struct _DateTimeWidgetsGridClass DateTimeWidgetsGridClass;
typedef struct _DateTimeWidgetsGridPrivate DateTimeWidgetsGridPrivate;

#define DATE_TIME_WIDGETS_TYPE_GRID_DAY (date_time_widgets_grid_day_get_type ())
#define DATE_TIME_WIDGETS_GRID_DAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATE_TIME_WIDGETS_TYPE_GRID_DAY, DateTimeWidgetsGridDay))
#define DATE_TIME_WIDGETS_GRID_DAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATE_TIME_WIDGETS_TYPE_GRID_DAY, DateTimeWidgetsGridDayClass))
#define DATE_TIME_WIDGETS_IS_GRID_DAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATE_TIME_WIDGETS_TYPE_GRID_DAY))
#define DATE_TIME_WIDGETS_IS_GRID_DAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATE_TIME_WIDGETS_TYPE_GRID_DAY))
#define DATE_TIME_WIDGETS_GRID_DAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATE_TIME_WIDGETS_TYPE_GRID_DAY, DateTimeWidgetsGridDayClass))

typedef struct _DateTimeWidgetsGridDay DateTimeWidgetsGridDay;
typedef struct _DateTimeWidgetsGridDayClass DateTimeWidgetsGridDayClass;
typedef struct _DateTimeWidgetsGridDayPrivate DateTimeWidgetsGridDayPrivate;

#define DATE_TIME_SERVICES_TYPE_TIME_MANAGER (date_time_services_time_manager_get_type ())
#define DATE_TIME_SERVICES_TIME_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATE_TIME_SERVICES_TYPE_TIME_MANAGER, DateTimeServicesTimeManager))
#define DATE_TIME_SERVICES_TIME_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATE_TIME_SERVICES_TYPE_TIME_MANAGER, DateTimeServicesTimeManagerClass))
#define DATE_TIME_SERVICES_IS_TIME_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATE_TIME_SERVICES_TYPE_TIME_MANAGER))
#define DATE_TIME_SERVICES_IS_TIME_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATE_TIME_SERVICES_TYPE_TIME_MANAGER))
#define DATE_TIME_SERVICES_TIME_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATE_TIME_SERVICES_TYPE_TIME_MANAGER, DateTimeServicesTimeManagerClass))

typedef struct _DateTimeServicesTimeManager DateTimeServicesTimeManager;
typedef struct _DateTimeServicesTimeManagerClass DateTimeServicesTimeManagerClass;
typedef struct _DateTimeServicesTimeManagerPrivate DateTimeServicesTimeManagerPrivate;

struct _UtilDateIterator {
	GObject parent_instance;
	UtilDateIteratorPrivate * priv;
};

struct _UtilDateIteratorClass {
	GObjectClass parent_class;
};

struct _UtilDateRange {
	GObject parent_instance;
	UtilDateRangePrivate * priv;
};

struct _UtilDateRangeClass {
	GObjectClass parent_class;
};

struct _DateTimeIndicator {
	WingpanelIndicator parent_instance;
	DateTimeIndicatorPrivate * priv;
};

struct _DateTimeIndicatorClass {
	WingpanelIndicatorClass parent_class;
};

struct _DateTimeComponentRow {
	GtkListBoxRow parent_instance;
	DateTimeComponentRowPrivate * priv;
};

struct _DateTimeComponentRowClass {
	GtkListBoxRowClass parent_class;
};

struct _DateTimeWidgetsPanelLabel {
	GtkBox parent_instance;
	DateTimeWidgetsPanelLabelPrivate * priv;
};

struct _DateTimeWidgetsPanelLabelClass {
	GtkBoxClass parent_class;
};

struct _DateTimeWidgetsCalendarModel {
	GObject parent_instance;
	DateTimeWidgetsCalendarModelPrivate * priv;
};

struct _DateTimeWidgetsCalendarModelClass {
	GObjectClass parent_class;
};

struct _DateTimeWidgetsCalendarView {
	GtkGrid parent_instance;
	DateTimeWidgetsCalendarViewPrivate * priv;
};

struct _DateTimeWidgetsCalendarViewClass {
	GtkGridClass parent_class;
};

struct _DateTimeWidgetsGrid {
	GtkGrid parent_instance;
	DateTimeWidgetsGridPrivate * priv;
};

struct _DateTimeWidgetsGridClass {
	GtkGridClass parent_class;
};

struct _DateTimeWidgetsGridDay {
	GtkEventBox parent_instance;
	DateTimeWidgetsGridDayPrivate * priv;
};

struct _DateTimeWidgetsGridDayClass {
	GtkEventBoxClass parent_class;
};

struct _DateTimeServicesTimeManager {
	GtkCalendar parent_instance;
	DateTimeServicesTimeManagerPrivate * priv;
};

struct _DateTimeServicesTimeManagerClass {
	GtkCalendarClass parent_class;
};

VALA_EXTERN GType util_date_iterator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (UtilDateIterator, g_object_unref)
VALA_EXTERN GType util_date_range_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (UtilDateRange, g_object_unref)
VALA_EXTERN UtilDateIterator* util_date_iterator_new (UtilDateRange* range);
VALA_EXTERN UtilDateIterator* util_date_iterator_construct (GType object_type,
                                                UtilDateRange* range);
VALA_EXTERN GDateTime* util_date_iterator_get_current (UtilDateIterator* self);
VALA_EXTERN void util_date_iterator_set_current (UtilDateIterator* self,
                                     GDateTime* value);
VALA_EXTERN UtilDateRange* util_date_iterator_get_range (UtilDateIterator* self);
VALA_EXTERN UtilDateRange* util_date_range_new (GDateTime* first,
                                    GDateTime* last);
VALA_EXTERN UtilDateRange* util_date_range_construct (GType object_type,
                                          GDateTime* first,
                                          GDateTime* last);
VALA_EXTERN gboolean util_date_range_equals (UtilDateRange* self,
                                 UtilDateRange* other);
VALA_EXTERN GeeList* util_date_range_to_list (UtilDateRange* self);
VALA_EXTERN GDateTime* util_date_range_get_first_dt (UtilDateRange* self);
VALA_EXTERN GDateTime* util_date_range_get_last_dt (UtilDateRange* self);
VALA_EXTERN GType date_time_indicator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DateTimeIndicator, g_object_unref)
VALA_EXTERN GSettings* date_time_indicator_settings;
VALA_EXTERN DateTimeIndicator* date_time_indicator_new (void);
VALA_EXTERN DateTimeIndicator* date_time_indicator_construct (GType object_type);
VALA_EXTERN WingpanelIndicator* get_indicator (GModule* module,
                                   WingpanelIndicatorManagerServerType server_type);
VALA_EXTERN GType date_time_component_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DateTimeComponentRow, g_object_unref)
VALA_EXTERN DateTimeComponentRow* date_time_component_row_new (GDateTime* date,
                                                   ICalComponent* component,
                                                   ESource* source);
VALA_EXTERN DateTimeComponentRow* date_time_component_row_construct (GType object_type,
                                                         GDateTime* date,
                                                         ICalComponent* component,
                                                         ESource* source);
VALA_EXTERN GDateTime* date_time_component_row_get_date (DateTimeComponentRow* self);
VALA_EXTERN ICalComponent* date_time_component_row_get_component (DateTimeComponentRow* self);
VALA_EXTERN ESourceSelectable* date_time_component_row_get_source_selectable (DateTimeComponentRow* self);
VALA_EXTERN GDateTime* date_time_component_row_get_start_time (DateTimeComponentRow* self);
VALA_EXTERN GDateTime* date_time_component_row_get_end_time (DateTimeComponentRow* self);
VALA_EXTERN gboolean date_time_component_row_get_is_allday (DateTimeComponentRow* self);
VALA_EXTERN GType date_time_widgets_panel_label_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DateTimeWidgetsPanelLabel, g_object_unref)
VALA_EXTERN DateTimeWidgetsPanelLabel* date_time_widgets_panel_label_new (void);
VALA_EXTERN DateTimeWidgetsPanelLabel* date_time_widgets_panel_label_construct (GType object_type);
VALA_EXTERN const gchar* date_time_widgets_panel_label_get_clock_format (DateTimeWidgetsPanelLabel* self);
VALA_EXTERN void date_time_widgets_panel_label_set_clock_format (DateTimeWidgetsPanelLabel* self,
                                                     const gchar* value);
VALA_EXTERN gboolean date_time_widgets_panel_label_get_clock_show_seconds (DateTimeWidgetsPanelLabel* self);
VALA_EXTERN void date_time_widgets_panel_label_set_clock_show_seconds (DateTimeWidgetsPanelLabel* self,
                                                           gboolean value);
VALA_EXTERN gboolean date_time_widgets_panel_label_get_clock_show_weekday (DateTimeWidgetsPanelLabel* self);
VALA_EXTERN void date_time_widgets_panel_label_set_clock_show_weekday (DateTimeWidgetsPanelLabel* self,
                                                           gboolean value);
VALA_EXTERN GType date_time_widgets_calendar_model_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DateTimeWidgetsCalendarModel, g_object_unref)
VALA_EXTERN DateTimeWidgetsCalendarModel* date_time_widgets_calendar_model_get_default (ECalClientSourceType source_type);
VALA_EXTERN DateTimeWidgetsCalendarModel* date_time_widgets_calendar_model_new (ECalClientSourceType source_type);
VALA_EXTERN DateTimeWidgetsCalendarModel* date_time_widgets_calendar_model_construct (GType object_type,
                                                                          ECalClientSourceType source_type);
VALA_EXTERN void date_time_widgets_calendar_model_change_month (DateTimeWidgetsCalendarModel* self,
                                                    gint relative);
VALA_EXTERN void date_time_widgets_calendar_model_change_year (DateTimeWidgetsCalendarModel* self,
                                                   gint relative);
VALA_EXTERN UtilDateRange* date_time_widgets_calendar_model_get_data_range (DateTimeWidgetsCalendarModel* self);
VALA_EXTERN GDateTime* date_time_widgets_calendar_model_get_month_start (DateTimeWidgetsCalendarModel* self);
VALA_EXTERN void date_time_widgets_calendar_model_set_month_start (DateTimeWidgetsCalendarModel* self,
                                                       GDateTime* value);
VALA_EXTERN gint date_time_widgets_calendar_model_get_num_weeks (DateTimeWidgetsCalendarModel* self);
VALA_EXTERN GDateWeekday date_time_widgets_calendar_model_get_week_starts_on (DateTimeWidgetsCalendarModel* self);
VALA_EXTERN void date_time_widgets_calendar_model_set_week_starts_on (DateTimeWidgetsCalendarModel* self,
                                                          GDateWeekday value);
VALA_EXTERN GHashTable* date_time_widgets_calendar_model_get_source_components (DateTimeWidgetsCalendarModel* self);
VALA_EXTERN ECalClientSourceType date_time_widgets_calendar_model_get_source_type (DateTimeWidgetsCalendarModel* self);
VALA_EXTERN GType date_time_widgets_calendar_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DateTimeWidgetsCalendarView, g_object_unref)
VALA_EXTERN void date_time_widgets_calendar_view_show_date_in_maya (DateTimeWidgetsCalendarView* self,
                                                        GDateTime* date);
VALA_EXTERN void date_time_widgets_calendar_view_refresh (DateTimeWidgetsCalendarView* self);
VALA_EXTERN DateTimeWidgetsCalendarView* date_time_widgets_calendar_view_new (void);
VALA_EXTERN DateTimeWidgetsCalendarView* date_time_widgets_calendar_view_construct (GType object_type);
VALA_EXTERN GDateTime* date_time_widgets_calendar_view_get_selected_date (DateTimeWidgetsCalendarView* self);
VALA_EXTERN GType date_time_widgets_grid_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DateTimeWidgetsGrid, g_object_unref)
VALA_EXTERN void date_time_widgets_grid_set_focus_to_today (DateTimeWidgetsGrid* self);
VALA_EXTERN void date_time_widgets_grid_set_range (DateTimeWidgetsGrid* self,
                                       UtilDateRange* new_range,
                                       GDateTime* month_start);
VALA_EXTERN void date_time_widgets_grid_update_weeks (DateTimeWidgetsGrid* self,
                                          GDateTime* date,
                                          gint nr_of_weeks);
VALA_EXTERN void date_time_widgets_grid_update_today (DateTimeWidgetsGrid* self);
VALA_EXTERN DateTimeWidgetsGrid* date_time_widgets_grid_new (void);
VALA_EXTERN DateTimeWidgetsGrid* date_time_widgets_grid_construct (GType object_type);
VALA_EXTERN UtilDateRange* date_time_widgets_grid_get_grid_range (DateTimeWidgetsGrid* self);
VALA_EXTERN GType date_time_widgets_grid_day_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DateTimeWidgetsGridDay, g_object_unref)
VALA_EXTERN DateTimeWidgetsGridDay* date_time_widgets_grid_day_new (GDateTime* date);
VALA_EXTERN DateTimeWidgetsGridDay* date_time_widgets_grid_day_construct (GType object_type,
                                                              GDateTime* date);
VALA_EXTERN void date_time_widgets_grid_day_add_component_dot (DateTimeWidgetsGridDay* self,
                                                   ESource* source,
                                                   ICalComponent* ical);
VALA_EXTERN void date_time_widgets_grid_day_remove_component_dot (DateTimeWidgetsGridDay* self,
                                                      const gchar* component_uid);
VALA_EXTERN void date_time_widgets_grid_day_set_selected (DateTimeWidgetsGridDay* self,
                                              gboolean selected);
VALA_EXTERN void date_time_widgets_grid_day_grab_focus_force (DateTimeWidgetsGridDay* self);
VALA_EXTERN void date_time_widgets_grid_day_sensitive_container (DateTimeWidgetsGridDay* self,
                                                     gboolean sens);
VALA_EXTERN GDateTime* date_time_widgets_grid_day_get_date (DateTimeWidgetsGridDay* self);
VALA_EXTERN void date_time_widgets_grid_day_set_date (DateTimeWidgetsGridDay* self,
                                          GDateTime* value);
VALA_EXTERN GDateTime* util_get_start_of_month (GDateTime* date);
VALA_EXTERN GDateTime* util_strip_time (GDateTime* datetime);
VALA_EXTERN GTimeZone* util_timezone_from_ical (ICalTime* date);
VALA_EXTERN GDateTime* util_ical_to_date_time (ICalTime* date);
VALA_EXTERN gboolean util_is_the_all_day (GDateTime* dtstart,
                              GDateTime* dtend);
VALA_EXTERN void util_set_component_calendar_color (ESourceSelectable* selectable,
                                        GtkWidget* widget);
VALA_EXTERN guint util_source_hash_func (ESource* key);
VALA_EXTERN gboolean util_calcomponent_equal_func (ECalComponent* a,
                                       ECalComponent* b);
VALA_EXTERN gint util_calcomponent_compare_func (ECalComponent* a,
                                     ECalComponent* b);
VALA_EXTERN gboolean util_calcomp_is_on_day (ECalComponent* comp,
                                 GDateTime* day);
VALA_EXTERN gboolean util_source_equal_func (ESource* a,
                                 ESource* b);
VALA_EXTERN GType date_time_services_time_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DateTimeServicesTimeManager, g_object_unref)
VALA_EXTERN DateTimeServicesTimeManager* date_time_services_time_manager_new (void);
VALA_EXTERN DateTimeServicesTimeManager* date_time_services_time_manager_construct (GType object_type);
VALA_EXTERN gchar* date_time_services_time_manager_format (DateTimeServicesTimeManager* self,
                                               const gchar* format);
VALA_EXTERN GDateTime* date_time_services_time_manager_get_current_time (DateTimeServicesTimeManager* self);
VALA_EXTERN DateTimeServicesTimeManager* date_time_services_time_manager_get_default (void);
VALA_EXTERN gboolean date_time_services_time_manager_get_clock_show_seconds (DateTimeServicesTimeManager* self);
VALA_EXTERN void date_time_services_time_manager_set_clock_show_seconds (DateTimeServicesTimeManager* self,
                                                             gboolean value);
VALA_EXTERN gboolean date_time_services_time_manager_get_is_12h (DateTimeServicesTimeManager* self);
VALA_EXTERN void date_time_services_time_manager_set_is_12h (DateTimeServicesTimeManager* self,
                                                 gboolean value);

G_END_DECLS

#endif
